@@ -71,13 +71,19 @@ namespace Ark
 static quint32 s_instanceCounter = 1;
 
 Part::Part(QWidget *parentWidget, QObject *parent, const KPluginMetaData &metaData, const QVariantList& args)
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
         : KParts::ReadWritePart(parent),
+#else
+        : KParts::ReadWritePart(parent, metaData),
+#endif
           m_splitter(nullptr),
           m_busy(false),
           m_jobTracker(nullptr)
 {
     Q_UNUSED(args)
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     setMetaData(metaData);
+#endif
 
     new DndExtractAdaptor(this);
 
@@ -219,12 +225,15 @@ Part::~Part()
 {
     qDeleteAll(m_tmpExtractDirList);
 
-    // Only save splitterSizes if infopanel is visible,
-    // because we don't want to store zero size for infopanel.
-    if (m_showInfoPanelAction->isChecked()) {
-        ArkSettings::setSplitterSizes(m_splitter->sizes());
+    // save the state of m_infoPanel only if it's embedded
+    if (m_splitter->indexOf(m_infoPanel) >= 0) {
+        // Only save splitterSizes if infopanel is visible,
+        // because we don't want to store zero size for infopanel.
+        if (m_showInfoPanelAction->isChecked()) {
+            ArkSettings::setSplitterSizes(m_splitter->sizes());
+        }
+        ArkSettings::setShowInfoPanel(m_showInfoPanelAction->isChecked());
     }
-    ArkSettings::setShowInfoPanel(m_showInfoPanelAction->isChecked());
     ArkSettings::self()->save();
 
     m_extractArchiveAction->menu()->deleteLater();
@@ -820,6 +829,11 @@ QList<Kerfuffle::SettingsPage*> Part::settingsPages(QWidget *parent) const
     return pages;
 }
 
+QWidget* Part::infoPanel() const
+{
+    return m_infoPanel;
+}
+
 bool Part::isLocalFileValid()
 {
     const QString localFile = localFilePath();
@@ -1502,7 +1516,7 @@ void Part::slotRenameFile(const QString &name)
 
     m_destination = new Archive::Entry();
     const QString &entryPath = entry->fullPath(NoTrailingSlash);
-    const QString rootPath = entryPath.left(entryPath.count() - entry->name().count());
+    const QString rootPath = entryPath.left(entryPath.length() - entry->name().length());
     QString path = rootPath + name;
     if (entry->isDir()) {
         path += QLatin1Char('/');
